pub fn module_manifests() -> Vec<ModuleManifest>Expand description
Context-free module manifests for read-only / OpenAPI paths that have no
AppContext. Kept in sync with modules by listing the same modules.
pub fn module_manifests() -> Vec<ModuleManifest>Context-free module manifests for read-only / OpenAPI paths that have no
AppContext. Kept in sync with modules by listing the same modules.